@@ -1,14 +1,14 @@
+from __future__ import annotations
+
 from media_platform.job.job import Job
 from media_platform.lang.serialization import Deserializable
 
 
 class JobCallbackPayload(Deserializable):
-    def __init__(self, job, attachment=None):
-        # type: (Job, dict or None) -> None
+    def __init__(self, job: Job, attachment: dict = None):
         self.job = job
         self.attachment = attachment
 
     @classmethod
-    def deserialize(cls, data):
-        # type: (dict) -> JobCallbackPayload
+    def deserialize(cls, data: dict) -> JobCallbackPayload:
         return cls(Job.deserialize(data['job']), data.get('attachment'))
