@@ -1,3 +1,3 @@
-class StreamProtocol(object):
+class StreamProtocol:
     rtmp = 'rtmp'
     webrtc = 'webrtc'
\ No newline at end of file
